@@ -2,10 +2,13 @@ test_that("fct_calculate_network_info::calculate_connectivity() works", {
   expect_true(igraph::vertex_connectivity(true_graph) == true_connectivity)
 })
 
+
 test_that("fct_calculate_network_info::calculate_modularity() works", {
-  expect_equal(calculate_modularity(true_graph_louvain), true_modularity, tolerance = 1e-3)
+  expect_equal(calculate_modularity(true_clustering), true_modularity)
 })
 
+
+
 test_that("fct_calculate_network_info::calculate_number_nodes_edges() works", {
   output <- calculate_number_nodes_edges(true_nodes, true_edges, TRUE)
   expect_equal(output$n_mineral_nodes, true_n_mineral_nodes)
